@@ -1,7 +1,9 @@
+"""GitHub Advanced Security Toolkit."""
+
 __name__ = "ghastoolkit"
 __title__ = "GHAS Toolkit"
 
-__version__ = "0.4.1"
+__version__ = "0.17.5"
 
 __description__ = "GitHub Advanced Security Python Toolkit"
 __summary__ = """\
@@ -21,24 +23,36 @@ __banner__ = f"""\
 | |  \\/| |_| |/ /_\\ \\\\ `--.  | | ___   ___ | | | ___| |_ 
 | | __ |  _  ||  _  | `--. \\ | |/ _ \\ / _ \\| | |/ / | __|
 | |_\\ \\| | | || | | |/\\__/ / | | (_) | (_) | |   <| | |_ 
- \\____/\\_| |_/\\_| |_/\\____/  \\_/\\___/ \\___/|_|_|\\_\\_|\\__| v{__version__} 
+ \\____/\\_| |_/\\_| |_/\\____/  \\_/\\___/ \\___/|_|_|\\_\\_|\\__|  v{__version__} by {__author__}
 """
 
 
+from ghastoolkit.errors import *
+
 # Octokit
-from ghastoolkit.octokit.github import GitHub, Repository
+from ghastoolkit.octokit.github import GitHub
+from ghastoolkit.octokit.repository import Repository
+from ghastoolkit.octokit.enterprise import Enterprise, Organization
 from ghastoolkit.octokit.octokit import Octokit, RestRequest, GraphQLRequest
 from ghastoolkit.octokit.codescanning import CodeScanning, CodeAlert
 from ghastoolkit.octokit.secretscanning import SecretScanning, SecretAlert
 from ghastoolkit.octokit.dependencygraph import DependencyGraph
+from ghastoolkit.octokit.dependabot import Dependabot
+from ghastoolkit.octokit.advisories import SecurityAdvisories
 
 # Supply Chain
-from ghastoolkit.supplychain.advisories import Advisory
+from ghastoolkit.supplychain.advisories import Advisory, Advisories
 from ghastoolkit.supplychain.dependencyalert import DependencyAlert
-from ghastoolkit.supplychain.dependencies import Dependency, Dependencies
+from ghastoolkit.supplychain.dependencies import Dependencies
+from ghastoolkit.supplychain.dependency import Dependency
 from ghastoolkit.supplychain.licensing import Licenses
 
 # CodeQL
 from ghastoolkit.codeql.databases import CodeQLDatabases, CodeQLDatabase
 from ghastoolkit.codeql.cli import CodeQL
-from ghastoolkit.codeql.results import CodeQLResults
+from ghastoolkit.codeql.packs.pack import CodeQLPack
+from ghastoolkit.codeql.packs.packs import CodeQLPacks
+from ghastoolkit.codeql.results import CodeQLResults, CodeLocation, CodeResult
+
+# CodeQL Data Extensions / Models as Data
+from ghastoolkit.codeql.dataextensions.ext import DataExtensions
